@@ -40,7 +40,7 @@ if "core_curate_registry_app" in INSTALLED_APPS:
 
 @login_required(login_url=reverse_lazy("core_main_app_login"))
 def home(request):
-    """ Home page.
+    """Home page.
 
     Args:
         request:
@@ -65,11 +65,10 @@ def home(request):
 
 
 class DashboardRegistryRecords(DashboardRecords):
-    """ List the records for the registry
-    """
+    """List the records for the registry"""
 
     def _get_list_name_in_shema_from_slug(self, role_name_list, custom_resources):
-        """ Get list of name in schema for each role in request
+        """Get list of name in schema for each role in request
 
         Args:
             role_name_list:
@@ -85,14 +84,14 @@ class DashboardRegistryRecords(DashboardRecords):
         return list_name_in_schema
 
     def load_records(self, request, is_published, custom_resources):
-        """ Get list of records
+        """Get list of records
 
-             Args:
-                 role_name_list:
-                 custom_resources:
-             Returns:
-                 filtered_data
-             """
+        Args:
+            role_name_list:
+            custom_resources:
+        Returns:
+            filtered_data
+        """
         role_name_list = self._get_list_name_in_shema_from_slug(
             request.GET.getlist("role", []), custom_resources
         )
@@ -116,14 +115,14 @@ class DashboardRegistryRecords(DashboardRecords):
         return filtered_data
 
     def load_drafts(self, request, context):
-        """ Get list of drafts
+        """Get list of drafts
 
-             Args:
-                 request:
-                 context:
-             Returns:
-                 filtered_data
-             """
+        Args:
+            request:
+            context:
+        Returns:
+            filtered_data
+        """
 
         role_name_list = request.GET.getlist("role", [])
         filtered_data = []
@@ -140,7 +139,9 @@ class DashboardRegistryRecords(DashboardRecords):
             try:
                 role = ", ".join(
                     [
-                        custom_resource_api.get_by_role_for_current_template(x).title
+                        custom_resource_api.get_by_role_for_current_template(
+                            x, request=request
+                        ).title
                         for x in curate_data_structure_registry_api.get_role(form)
                     ]
                     if form.form_string
@@ -157,7 +158,7 @@ class DashboardRegistryRecords(DashboardRecords):
         return filtered_data
 
     def get(self, request, *args, **kwargs):
-        """ Retrieve a list of drafts or records
+        """Retrieve a list of drafts or records
 
         Args:
 
@@ -174,10 +175,14 @@ class DashboardRegistryRecords(DashboardRecords):
         """
 
         # TODO: use custom_resource to get cr_type_all
-        cr_type_all = custom_resource_api.get_current_custom_resource_type_all()
+        cr_type_all = custom_resource_api.get_current_custom_resource_type_all(
+            request=request
+        )
 
         custom_resources = list(
-            custom_resource_api.get_all_of_current_template().order_by("sort")
+            custom_resource_api.get_all_of_current_template(request=request).order_by(
+                "sort"
+            )
         )
         # Get arguments
 
@@ -273,7 +278,10 @@ class DashboardRegistryRecords(DashboardRecords):
                     "data_status": get_status(data),
                     "data_status_values": DataStatus,
                     "data_role": ", ".join(
-                        [_get_role_label(x) for x in get_role(data)]
+                        [
+                            _get_role_label(x, request=self.request)
+                            for x in get_role(data)
+                        ]
                     ),
                     "can_read": True,
                     "can_write": True,
@@ -320,8 +328,7 @@ class DashboardRegistryRecords(DashboardRecords):
 
 
 class DashboardRegistryWorkspaceRecords(DashboardWorkspaceRecords):
-    """ List the records of a workspace for the registry.
-    """
+    """List the records of a workspace for the registry."""
 
     def _format_data_context(self, data_list, user, user_can_read, user_can_write):
         detailed_user_data = []
@@ -335,7 +342,10 @@ class DashboardRegistryWorkspaceRecords(DashboardWorkspaceRecords):
                     "data_status": get_status(data),
                     "data_status_values": DataStatus,
                     "data_role": ", ".join(
-                        [_get_role_label(x) for x in get_role(data)]
+                        [
+                            _get_role_label(x, request=self.request)
+                            for x in get_role(data)
+                        ]
                     ),
                     "can_read": user_can_read or is_owner,
                     "can_write": user_can_write or is_owner,
@@ -375,8 +385,7 @@ class DashboardRegistryWorkspaceRecords(DashboardWorkspaceRecords):
 
 
 class DashboardRegistryForms(DashboardForms):
-    """ List the forms.
-    """
+    """List the forms."""
 
     def _get_detailed_forms(self, forms):
         detailed_forms = []
@@ -384,7 +393,9 @@ class DashboardRegistryForms(DashboardForms):
             try:
                 role = ", ".join(
                     [
-                        custom_resource_api.get_by_role_for_current_template(x).title
+                        custom_resource_api.get_by_role_for_current_template(
+                            x, request=self.request
+                        ).title
                         for x in curate_data_structure_registry_api.get_role(form)
                     ]
                     if form.form_string
@@ -397,8 +408,8 @@ class DashboardRegistryForms(DashboardForms):
         return detailed_forms
 
 
-def _get_role_label(role):
-    """ Get role label
+def _get_role_label(role, request):
+    """Get role label
 
     Get role label from custom resources if found, get it from xsd otherwise
 
@@ -409,6 +420,8 @@ def _get_role_label(role):
 
     """
     try:
-        return custom_resource_api.get_by_role_for_current_template(role).title
+        return custom_resource_api.get_by_role_for_current_template(
+            role, request=request
+        ).title
     except (exceptions.ModelError, exceptions.DoesNotExist):
         return role
